@@ -1,7 +1,7 @@
 package File::Digest;
 
-our $DATE = '2017-07-10'; # DATE
-our $VERSION = '0.007'; # VERSION
+our $DATE = '2019-08-21'; # DATE
+our $VERSION = '0.008'; # VERSION
 
 use 5.010001;
 use strict;
@@ -22,6 +22,7 @@ $SPEC{':package'} = {
 
 my %arg_file = (
     file => {
+        summary => 'Filename ("-" means stdin)',
         schema => ['filename*'],
         req => 1,
         pos => 0,
@@ -33,6 +34,7 @@ my %arg_files = (
     files => {
         'x.name.is_plural' => 1,
         'x.name.singular' => 'file',
+        summary => 'Array of filenames (filename "-" means stdin)',
         schema => ['array*', of=>'filename*'],
         req => 1,
         pos => 0,
@@ -68,15 +70,20 @@ sub digest_file {
     my $file = $args{file};
     my $algo = $args{algorithm} // 'md5';
 
-    unless (-f $file) {
-        log_warn("Can't open %s: no such file", $file);
-        return [404, "No such file '$file'"];
+    my $fh;
+    if ($file eq '-') {
+        $fh = \*STDIN;
+    } else {
+        unless (-f $file) {
+            log_warn("Can't open %s: no such file", $file);
+            return [404, "No such file '$file'"];
+        }
+        open $fh, "<", $file or do {
+            log_warn("Can't open %s: %s", $file, $!);
+            return [500, "Can't open '$file': $!"];
+        };
     }
-    open my($fh), "<", $file or do {
-        log_warn("Can't open %s: %s", $file, $!);
-        return [500, "Can't open '$file': $!"];
-        next;
-    };
+
     if ($algo eq 'md5') {
         require Digest::MD5;
         my $ctx = Digest::MD5->new;
@@ -147,7 +154,7 @@ File::Digest - Calculate file checksum/digest (using various algorithms)
 
 =head1 VERSION
 
-This document describes version 0.007 of File::Digest (from Perl distribution File-Digest), released on 2017-07-10.
+This document describes version 0.008 of File::Digest (from Perl distribution File-Digest), released on 2019-08-21.
 
 =head1 SYNOPSIS
 
@@ -167,7 +174,7 @@ This document describes version 0.007 of File::Digest (from Perl distribution Fi
 
 Usage:
 
- digest_file(%args) -> [status, msg, result, meta]
+ digest_file(%args) -> [status, msg, payload, meta]
 
 Calculate file checksum/digest (using various algorithms).
 
@@ -183,6 +190,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<file>* => I<filename>
 
+Filename ("-" means stdin).
+
 =back
 
 Returns an enveloped result (an array).
@@ -190,18 +199,19 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
 
 
+
 =head2 digest_files
 
 Usage:
 
- digest_files(%args) -> [status, msg, result, meta]
+ digest_files(%args) -> [status, msg, payload, meta]
 
 Calculate file checksum/digest (using various algorithms).
 
@@ -217,6 +227,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<files>* => I<array[filename]>
 
+Array of filenames (filename "-" means stdin).
+
 =back
 
 Returns an enveloped result (an array).
@@ -224,7 +236,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -261,7 +273,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
